.. uniqed documentation master file, created by
   sphinx-quickstart on Fri Nov 20 21:40:16 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to uniqed's documentation!
==================================


This is a python implementation of the Temporal Outlier Factor [1]_ (TOF) anomaly detection method.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
  installation
  example
  resources
  license

.. include:: installation.rst
.. include:: example.rst
.. include:: resources.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`